summaryrefslogtreecommitdiff
path: root/tests/vb2_recovery_reasons_tests.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/vb2_recovery_reasons_tests.c')
-rw-r--r--tests/vb2_recovery_reasons_tests.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/vb2_recovery_reasons_tests.c b/tests/vb2_recovery_reasons_tests.c
index c1cb95b6..5def4d21 100644
--- a/tests/vb2_recovery_reasons_tests.c
+++ b/tests/vb2_recovery_reasons_tests.c
@@ -17,10 +17,10 @@ static void get_recovery_reason_string_tests(void)
TEST_PTR_NEQ(vb2_get_recovery_reason_string(i), NULL,
"Non-null reason");
/* Sanity check on one of the strings */
TEST_EQ(strcmp(vb2_get_recovery_reason_string(VB2_RECOVERY_GBB_HEADER),
"Error parsing GBB header"), 0,
- "Recovery reason sanity check");
+ "Recovery reason validity check");
}
int main(void)
@@ -17,10 +17,10 @@ static void get_recovery_reason_string_tests(void)
TEST_PTR_NEQ(vb2_get_recovery_reason_string(i), NULL,
"Non-null reason");
- /* Sanity check on one of the strings */
+ /* Validity check on one of the strings */
TEST_EQ(strcmp(vb2_get_recovery_reason_string(VB2_RECOVERY_GBB_HEADER),
"Error parsing GBB header"), 0,